@@ -2,7 +2,7 @@
 """activity related views.
 
 :organization: Logilab
-:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -156,6 +156,8 @@ class ValidateActivitiesAction(action.Action):
         msg = self._cw._('activities validated')
         return self._cw.user_callback(validate_cb, (eids,), msg)
 
+WORKORDER_CLOSED_STATES = ('validated', 'canceled')
+
 class MoveActivitiesAction(action.Action):
     __regid__ = 'move-activities'
     __select__ = (action.Action.__select__
@@ -167,7 +169,11 @@ class MoveActivitiesAction(action.Action):
     submenu = _('move activities')
 
     def actual_actions(self):
-        for item in self._cw.execute('Any W WHERE W is WorkOrder, W in_state S, S name "open"').entities():
+        states = ','.join('"%s"' % state for state in WORKORDER_CLOSED_STATES)
+        for item in self._cw.execute('Any W,WT,O,OT ORDERBY OT,WT WHERE W is WorkOrder, '
+                                     'W in_state S, NOT S name IN (%s), '
+                                     'O split_into W, O title OT, W title WT'
+                                     % states).entities():
             yield self.build_action(item.dc_long_title(), self.url(item))
 
     def url(self, workorder):
